/*
 * Author: David Planella <david.planella@ubuntu.com>
 *
 * Copyright (c) 2010, 2011, 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
 * SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

google.load("visualization", "1", {
    packages: ["table"]
});

function drawLangTemplatesTable(data) {

    var template_table_data = new google.visualization.DataTable(data, 0.6);

    var template_table = new google.visualization.Table(
        document.getElementById('template_stats_table'));

    /* Format the data column containing the translation percentage
       value: show no decimal digits */
    var nr_formatter = new google.visualization.NumberFormat({
        fractionDigits: 0,
        suffix: ' %'
    });
    nr_formatter.format(template_table_data, 2);

    /* Format the data column containing the translation percentage
       value: show a green bar indicating the level of coverage */
    var bar_formatter = new google.visualization.BarFormat({
        min: 0,
        max: 100,
        width: 100,
        colorPositive: 'green'
    });
    bar_formatter.format(template_table_data, 2);

    /* Draw the template statistics table */
    template_table.draw(template_table_data, {
        allowHtml: true,
        showRowNumber: true,
        sortColumn: 1,
        sortAscending: false,
        page: 'enable',
        cssClassNames: {headerRow: 'table_header',
                        hoverTableRow: 'row_hover',
                        selectedTableRow: 'row_selected',
                        headerCell: 'table_header_cell_left'},
        pageSize: 50
    });
}

function drawProgressDiagram(coverage, untranslated) {
    var data = [
        { data: coverage, label: "Translation coverage" },
        { data: untranslated, label: "Untranslated messages", yaxis: 2},
    ];

    var options = {
        xaxes: [{
            mode: "time"
        }],
        yaxes: [
            {
                min: 0,
                max: 110,
                tickFormatter: function (v) { return v + " %"; },
            },
            {
                position: "right",
                minTickSize: 1,
                tickDecimals: 0,
            },
        ],
        grid: {
            hoverable: true,
            clickable: true
        },
        points: { show: true },
        legend: { position: 'sw' },
    };
    $.plot($("#diagram"), data, options);
}

function OnLoad() {
    drawLangTemplatesTable(template_data);
    drawProgressDiagram(coverage, untranslated);
}

google.setOnLoadCallback(OnLoad);
