google.load("visualization", "1", {
    packages: ["table", "intensitymap"]
});

var languages_supported = metadata.languages_supported;
var distro_release = metadata.distro_release;
var distro_codename = metadata.distro_codename;
var report_date = metadata.report_date;

/* From http://stackoverflow.com/questions/1462119/
   how-do-you-use-javascript-to-duplicate-form-fields/1462145#1462145 */
String.prototype.supplant = function (o) { 
    return this.replace(/{([^{}]*)}/g, 
        function (a, b) {  
            var r = o[b];
            return typeof r === 'string' ? 
                r : a;
        }
    ); 
};

function OnLoad(){
	initEvents();
	resetBreadcrumb(true);
	updateVars();
}

function updateVars(){
    $("#languages_supported").html(languages_supported);
    $("#distro_release").html(distro_release);
    $("#report_date").html(report_date);
}

function initEvents(){
	$("#breadcrumb > li#overview > a").click(function() {
  		resetBreadcrumb(false);
	});
}

function resetBreadcrumb(is_init){
	if (!(is_init)) {
		fx = "slow";
	}
	else {
		fx = "";
	}
	drawMap('data/' + distro_release + '/countries.json');
	drawOverviewTable('data/' + distro_release + '/langstats.json');
	$("#breadcrumb > li#overview").html("Overview");
	$("#breadcrumb > li#overview").next().hide(fx);
	$("#breadcrumb > li#language").hide(fx);
}

function addLangBreadcrumb(language){
	$("#breadcrumb > li#language").prev().show("fast");
    $("#breadcrumb > li#language").html(language);
    var language_nolink = $("#breadcrumb > li#language > a").html();
    $("#breadcrumb > li#language").html("<strong>" + language_nolink +
                                        "</strong>");
	$("#breadcrumb > li#language").show("fast");
	$("#breadcrumb > li#overview").html('<a href="#">Overview</a>');
	initEvents();
}

function linkifyValue(value, url){
    var params = {
        'url': url,
        'value': value
    };
    
    return '<a class="language_link" href="{url}">{value}</a>'.supplant(params);
}

function linkifyTableCol(DataTable, col, url) {
    var row_count = DataTable.getNumberOfRows();

    for (var i = 0; i < row_count; i++) {
        var value = DataTable.getValue(i, col);
        DataTable.setValue(i, col, linkifyValue(value, '#'));
    };
}

function linkifyTemplatesTable(language_table_data, lang_code,
                               distro_codename) {
    var lp_url =
        'https://translations.launchpad.net/ubuntu/{distro_codename}/' +
        '+source/{package_name}/+pots/{template_name}/{lang_code}/' +
        '+translate?show=untranslated';
    var row_count = language_table_data.getNumberOfRows();

    for (var i = 0; i < row_count; i++) {
        var package_name = language_table_data.getValue(i, 1);
        var template_name = language_table_data.getValue(i, 2);
        var params = {
            'package_name': package_name,
            'template_name': template_name,
            'lang_code': lang_code,
            'distro_codename': distro_codename
        };

        language_table_data.setValue(i, 2,
            linkifyValue(template_name, lp_url.supplant(params)));
    };
}

function drawOverviewTable(json_data){
    var jqxhr = $.getJSON(json_data,
    function(data){

        var language_table_data = new google.visualization.DataTable(data, 0.6);
        
        linkifyTableCol(language_table_data, 0, '#');

        var language_table = new google.visualization.Table(
        	document.getElementById('stats_table'));

        /* Format the data column containing the translation percentage
	       value: show no decimal digits */
        var nr_formatter = new google.visualization.NumberFormat({
            fractionDigits: 0,
            suffix: ' %'
        });

        nr_formatter.format(language_table_data, 2);

        /* Format the data column containing the translation percentage
	       value: show a green bar indicating the level of coverage */
        var bar_formatter = new google.visualization.BarFormat({
            min: 0,
            max: 100,
            width: 100,
            colorPositive: 'green'
        });

        bar_formatter.format(language_table_data, 2);

        /* Draw the statistics table, hiding the language code column */
       	var dv = new google.visualization.DataView(language_table_data);
    	dv.hideColumns([1]);

        language_table.draw(dv, {
            allowHtml: true,
            showRowNumber: true,
            page: 'enable',
            pageSize: languages_supported,
            cssClassNames: {headerRow: 'table_header',
                            hoverTableRow: 'row_hover',
                            selectedTableRow: 'row_selected',
                            headerCell: 'table_header_cell_left'}
        });

        google.visualization.events.addListener(language_table, 'select',
        function(){
            var row = language_table.getSelection()[0].row;
            lang_name = language_table_data.getValue(row, 0);
            lang_code = language_table_data.getValue(row, 1);
            drawLangTemplatesTable('data/' + distro_release + '/' + lang_code + 
                '.json', lang_code);
            addLangBreadcrumb(lang_name);
        });
    })
}

function drawLangTemplatesTable(json_data, lang_code){
    $.getJSON(json_data,
    function(data){ 		
        var language_table_data = new google.visualization.DataTable(data, 0.6);
        
        linkifyTemplatesTable(language_table_data, lang_code, distro_codename);
        
        var language_table = new google.visualization.Table(
        	document.getElementById('stats_table'));

       	var dv = new google.visualization.DataView(language_table_data);
    	dv.hideColumns([0, 1, 3]);
		
        language_table.draw(dv, {
            allowHtml: true,
            showRowNumber: true,
            page: 'enable',
            pageSize: 50,
            cssClassNames: {headerRow: 'table_header',
                            hoverTableRow: 'row_hover',
                            selectedTableRow: 'row_selected',
                            headerCell: 'table_header_cell_center'}
        });
    });
}

function drawMap(json_data){
    $.getJSON(json_data,
    function(data){ 		
        var map_data = new google.visualization.DataTable(data, 0.6);

       	var map = new google.visualization.IntensityMap(
       	    document.getElementById('stats_map'));
		
        map.draw(map_data, {
            colors: ['#DD4814'],
            height: 220,
            width: 420
        });
    });
}

google.setOnLoadCallback(OnLoad);

