from django import template
from django.template.defaultfilters import stringfilter

register = template.Library()


@register.filter
@stringfilter
def appnamify(appnameraw):
    '''When given an appname in the form "app" or "super-app", it returns a
    name that is more readable in natural languages (e.g. "App" or
    "Super App"). The main use case is when converting translation template
    names coming from Launchpad to app names, as in the vast majority of cases
    template names correspond to app names.

    '''
    acronyms = ['gnome', 'sso', 'gimp', 'kde', 'gtk', 'gtk+', 'oem', 'xsl']

    appwords = appnameraw.split('-')

    try:
        assert isinstance(appwords, basestring)
        appwords = list(appwords)
    except AssertionError:
        pass

    appname = []
    for word in appwords:
        if word in acronyms:
            appname.append(word.upper())
        else:
            appname.append(word.capitalize())

    return ' '.join(appname)
appnamify.is_safe = True
